from setuptools import setup, find_packages
filepath = 'README.md'
setup(
        name="cip",
        version="1.1",
        description="c/c++ install package",
        long_description=open(filepath, encoding='utf-8').read(),
        long_description_content_type="text/markdown",
        author="jdh99",
        author_email="jdh821@163.com",
        url="https://github.com/jdhxyy/cip",
        packages=find_packages(),
        data_files=[filepath]
    )



"""
Copyright 2021-2021 The jdh99 Authors. All rights reserved.
cip: C/C++ Install Package.C/C++下的包管理工具
Authors: jdh99 <jdh821@163.com>
"""

import git
import os


def set_lib_dir(path='.lib'):
    # if not os.path.exists(path):
    #     os.mkdir(path)
    print(os.getcwd())
